public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
* [PATCH v3 1/1] MdePkg/Cpuid.h: Change and add some macro definitions.
@ 2021-01-25  1:20 Jason Lou
  2021-01-25  1:55 ` 回复: [edk2-devel] " gaoliming
  0 siblings, 1 reply; 2+ messages in thread
From: Jason Lou @ 2021-01-25  1:20 UTC (permalink / raw)
  To: devel
  Cc: Jason, Michael D Kinney, Liming Gao, Zhiguang Liu, Ray Ni,
	Eric Dong, Laszlo Ersek, Rahul Kumar

REF: https://bugzilla.tianocore.org/show_bug.cgi?id=3105

Change and add some macro definitions about
CPUID_HYBRID_INFORMATION Leaf(1Ah).

Signed-off-by: Jason Lou <yun.lou@intel.com>
Cc: Michael D Kinney <michael.d.kinney@intel.com>
Cc: Liming Gao <gaoliming@byosoft.com.cn>
Cc: Zhiguang Liu <zhiguang.liu@intel.com>
Cc: Ray Ni <ray.ni@intel.com>
Cc: Eric Dong <eric.dong@intel.com>
Cc: Laszlo Ersek <lersek@redhat.com>
Cc: Rahul Kumar <rahul1.kumar@intel.com>
---
 UefiCpuPkg/Library/CpuCacheInfoLib/CpuCacheInfoLib.c |  2 +-
 MdePkg/Include/Register/Intel/Cpuid.h                | 19 ++++++++++++++-----
 2 files changed, 15 insertions(+), 6 deletions(-)

diff --git a/UefiCpuPkg/Library/CpuCacheInfoLib/CpuCacheInfoLib.c b/UefiCpuPkg/Library/CpuCacheInfoLib/CpuCacheInfoLib.c
index 6b87be261acf..d1f9830c91e7 100644
--- a/UefiCpuPkg/Library/CpuCacheInfoLib/CpuCacheInfoLib.c
+++ b/UefiCpuPkg/Library/CpuCacheInfoLib/CpuCacheInfoLib.c
@@ -175,7 +175,7 @@ CpuCacheInfoCollectCoreAndCacheData (
   //
   Context->ProcessorInfo[ProcessorIndex].CoreType = 0;
   if (CpuidMaxInput >= CPUID_HYBRID_INFORMATION) {
-    AsmCpuidEx (CPUID_HYBRID_INFORMATION, CPUID_HYBRID_INFORMATION_SUB_LEAF, &NativeModelIdAndCoreTypeEax.Uint32, NULL, NULL, NULL);
+    AsmCpuidEx (CPUID_HYBRID_INFORMATION, CPUID_HYBRID_INFORMATION_MAIN_LEAF, &NativeModelIdAndCoreTypeEax.Uint32, NULL, NULL, NULL);
     Context->ProcessorInfo[ProcessorIndex].CoreType = (UINT8) NativeModelIdAndCoreTypeEax.Bits.CoreType;
   }
 
diff --git a/MdePkg/Include/Register/Intel/Cpuid.h b/MdePkg/Include/Register/Intel/Cpuid.h
index dd1b64a1e50b..19af99b6afa7 100644
--- a/MdePkg/Include/Register/Intel/Cpuid.h
+++ b/MdePkg/Include/Register/Intel/Cpuid.h
@@ -3601,7 +3601,7 @@ typedef union {
   CPUID Hybrid Information Enumeration Leaf
 
   @param   EAX  CPUID_HYBRID_INFORMATION (0x1A)
-  @param   ECX  CPUID_HYBRID_INFORMATION_SUB_LEAF (0x00).
+  @param   ECX  CPUID_HYBRID_INFORMATION_MAIN_LEAF (0x00).
 
   @retval  EAX  Enumerates the native model ID and core type described
                 by the type CPUID_NATIVE_MODEL_ID_AND_CORE_TYPE_EAX
@@ -3615,7 +3615,7 @@ typedef union {
 
   AsmCpuidEx (
     CPUID_HYBRID_INFORMATION,
-    CPUID_HYBRID_INFORMATION_SUB_LEAF,
+    CPUID_HYBRID_INFORMATION_MAIN_LEAF,
     &Eax, NULL, NULL, NULL
     );
   @endcode
@@ -3624,13 +3624,13 @@ typedef union {
 #define CPUID_HYBRID_INFORMATION                                       0x1A
 
 ///
 /// CPUID Hybrid Information Enumeration sub-leaf
 ///
-#define CPUID_HYBRID_INFORMATION_SUB_LEAF                               0x00
+#define CPUID_HYBRID_INFORMATION_MAIN_LEAF                              0x00
 
 /**
   CPUID Hybrid Information EAX for CPUID leaf #CPUID_HYBRID_INFORMATION,
-  sub-leaf #CPUID_HYBRID_INFORMATION_SUB_LEAF.
+  main leaf #CPUID_HYBRID_INFORMATION_MAIN_LEAF.
 **/
 typedef union {
   ///
@@ -3657,6 +3657,15 @@ typedef union {
   UINT32  Uint32;
 } CPUID_NATIVE_MODEL_ID_AND_CORE_TYPE_EAX;
 
+///
+/// @{ Define value for CPUID_NATIVE_MODEL_ID_AND_CORE_TYPE_EAX.CoreType
+///
+#define   CPUID_CORE_TYPE_INTEL_ATOM                                    0x20
+#define   CPUID_CORE_TYPE_INTEL_CORE                                    0x40
+///
+/// @}
+///
+
 
 /**
   CPUID V2 Extended Topology Enumeration Leaf
@@ -3624,13 +3624,13 @@ typedef union {
 
 ///
-/// CPUID Hybrid Information Enumeration sub-leaf
+/// CPUID Hybrid Information Enumeration main leaf
 ///
-- 
2.28.0.windows.1


^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2021-01-25  1:55 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2021-01-25  1:20 [PATCH v3 1/1] MdePkg/Cpuid.h: Change and add some macro definitions Jason Lou
2021-01-25  1:55 ` 回复: [edk2-devel] " gaoliming

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox